{% extends 'base_app.html' %}

{% block content %}
<div class="max-w-4xl mx-auto py-10 px-4 sm:px-6 lg:px-8">
    <div class="mb-8">
        <h1 class="text-3xl font-bold text-gray-900">Bedrijfsinstellingen</h1>
        <p class="mt-1 text-sm text-gray-600">Beheer de gegevens van je organisatie.</p>
    </div>

    <div class="bg-white shadow rounded-lg overflow-hidden">
        <div class="px-4 py-5 border-b border-gray-200 sm:px-6 bg-gray-50">
            <h3 class="text-lg leading-6 font-medium text-gray-900">Organisatiegegevens</h3>
        </div>

        <form method="post" class="divide-y divide-gray-200">
            {% csrf_token %}

            <div class="px-4 py-6 sm:p-6 space-y-6">
            {% for field in form %}
                <div>
                    <label for="{{ field.id_for_label }}" class="block text-sm font-medium text-gray-700">
                        {{ field.label }}
                    </label>
                    <div class="mt-1">
                        {{ field }}
                    </div>
                    {% if field.errors %}
                        <p class="mt-2 text-sm text-red-600">{{ field.errors.0 }}</p>
                    {% endif %}
                </div>
            {% endfor %}
            </div>

            <div class="px-4 py-3 bg-gray-50 text-right sm:px-6">
                <button type="submit"
                        class="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-blue-600 hover:bg-blue-700 focus:outline-none transition-colors">
                    Opslaan
                </button>
            </div>
        </form>
    </div>
</div>
{% endblock %}